# coding: utf-8

"""
    RTU MIREA VUC

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.4.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from schedule_service_client.api.healthcheck_api import HealthcheckApi  # noqa: E501


class TestHealthcheckApi(unittest.TestCase):
    """HealthcheckApi unit test stubs"""

    def setUp(self) -> None:
        self.api = HealthcheckApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_health_health_get(self) -> None:
        """Test case for health_health_get

        Health  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
