# coding: utf-8

"""
    RTU MIREA VUC

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.4.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from schedule_service_client.models.week_schedule_result import WeekScheduleResult  # noqa: E501

class TestWeekScheduleResult(unittest.TestCase):
    """WeekScheduleResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WeekScheduleResult:
        """Test WeekScheduleResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WeekScheduleResult`
        """
        model = WeekScheduleResult()  # noqa: E501
        if include_optional:
            return WeekScheduleResult(
                platoon = schedule_service_client.models.platoon.Platoon(
                    specialty_code = 56, 
                    platoon_number = 56, ),
                schedule = schedule_service_client.models.week_schedule.WeekSchedule(
                    date = '', 
                    datetime = '', 
                    subjects = [
                        schedule_service_client.models.subject.Subject(
                            name = '', 
                            auditory = '', 
                            teacher = '', 
                            lesson = schedule_service_client.models.lesson.Lesson(
                                topic = 56, 
                                lesson = 56, 
                                type = '', ), )
                        ], 
                    coordinates = null, )
            )
        else:
            return WeekScheduleResult(
                platoon = schedule_service_client.models.platoon.Platoon(
                    specialty_code = 56, 
                    platoon_number = 56, ),
                schedule = schedule_service_client.models.week_schedule.WeekSchedule(
                    date = '', 
                    datetime = '', 
                    subjects = [
                        schedule_service_client.models.subject.Subject(
                            name = '', 
                            auditory = '', 
                            teacher = '', 
                            lesson = schedule_service_client.models.lesson.Lesson(
                                topic = 56, 
                                lesson = 56, 
                                type = '', ), )
                        ], 
                    coordinates = null, ),
        )
        """

    def testWeekScheduleResult(self):
        """Test WeekScheduleResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
