# coding: utf-8

"""
    RTU MIREA VUC

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.4.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from schedule_service_client.api.schedule_api import ScheduleApi  # noqa: E501


class TestScheduleApi(unittest.TestCase):
    """ScheduleApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ScheduleApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_get_days_week_api_v1_schedule_day_week_get(self) -> None:
        """Test case for get_days_week_api_v1_schedule_day_week_get

        Get Days Week  # noqa: E501
        """
        pass

    def test_get_platoons_api_v1_schedule_platoons_get(self) -> None:
        """Test case for get_platoons_api_v1_schedule_platoons_get

        Get Platoons  # noqa: E501
        """
        pass

    def test_get_schedule_api_v1_schedule_get(self) -> None:
        """Test case for get_schedule_api_v1_schedule_get

        Get Schedule  # noqa: E501
        """
        pass

    def test_get_week_schedule_api_v1_schedule_week_get(self) -> None:
        """Test case for get_week_schedule_api_v1_schedule_week_get

        Get Week Schedule  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
