# coding: utf-8

"""
    RTU MIREA VUC

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.4.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from schedule_service_client.api.workbook_api import WorkbookApi  # noqa: E501


class TestWorkbookApi(unittest.TestCase):
    """WorkbookApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkbookApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_get_course_workbook_api_v1_workbook_course_get(self) -> None:
        """Test case for get_course_workbook_api_v1_workbook_course_get

        Get Course Workbook  # noqa: E501
        """
        pass

    def test_get_course_workbook_relevance_api_v1_workbook_relevance_course_get(self) -> None:
        """Test case for get_course_workbook_relevance_api_v1_workbook_relevance_course_get

        Get Course Workbook Relevance  # noqa: E501
        """
        pass

    def test_get_workbooks_api_v1_workbook_get(self) -> None:
        """Test case for get_workbooks_api_v1_workbook_get

        Get Workbooks  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
